@@ -414,12 +414,7 @@ class ERP5Diff:
          </node>")
       tree.node.text == '\n    '
     """
-    for child in element:
-      if type(child) == etree._Element:
-        return True
-    if element.text is None:
-      return True
-    return bool(element.text.strip()) is False or False
+    return not [text for text in element.xpath('text()') if text.strip()]
 
   def _makeRelativePathList(self, element_list, before=0):
     """
