@@ -1111,5 +1111,25 @@ class TestERP5Diff(unittest.TestCase):
 
     self._assertERP5DiffWorks(old_xml, new_xml, expected_result_string)
 
+  def test_text_node_in_tails(self):
+    """31. Check tail of elements ...<node/>blablabla...
+    """
+    old_xml = """
+<ul>
+  <node/>blablabla
+</ul>
+"""
+    new_xml = """
+<ul>
+  <node/>yayaya
+</ul>
+"""
+    expected_result_string = """<xupdate:modifications xmlns:xupdate="http://www.xmldb.org/xupdate" version="1.0">
+  <xupdate:update select="/ul"><node/>yayaya
+</xupdate:update>
+</xupdate:modifications>
+"""
+    self._assertERP5DiffWorks(old_xml, new_xml, expected_result_string)
+
 if __name__ == '__main__':
   unittest.main()
